@@ -20,6 +20,7 @@
  ***************************************************************************/
 
 #include "dolphinmainwindow.h"
+#include "dolphinviewactionhandler.h"
 #include "dolphindropcontroller.h"
 
 #include <config-nepomuk.h>
@@ -176,140 +177,6 @@ void DolphinMainWindow::changeSelection(const KFileItemList& selection)
     activeViewContainer()->view()->changeSelection(selection);
 }
 
-void DolphinMainWindow::slotViewModeChanged()
-{
-    updateViewActions();
-}
-
-void DolphinMainWindow::slotShowPreviewChanged()
-{
-    // It is not enough to update the 'Show Preview' action, also
-    // the 'Zoom In' and 'Zoom Out' actions must be adapted.
-    updateViewActions();
-}
-
-void DolphinMainWindow::slotShowHiddenFilesChanged()
-{
-    KToggleAction* showHiddenFilesAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_hidden_files"));
-    const DolphinView* view = m_activeViewContainer->view();
-    showHiddenFilesAction->setChecked(view->showHiddenFiles());
-}
-
-void DolphinMainWindow::slotCategorizedSortingChanged()
-{
-    KToggleAction* showInGroupsAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_in_groups"));
-    const DolphinView* view = m_activeViewContainer->view();
-    showInGroupsAction->setChecked(view->categorizedSorting());
-    showInGroupsAction->setEnabled(view->supportsCategorizedSorting());
-}
-
-void DolphinMainWindow::slotSortingChanged(DolphinView::Sorting sorting)
-{
-    QAction* action = 0;
-    switch (sorting) {
-    case DolphinView::SortByName:
-        action = actionCollection()->action("sort_by_name");
-        break;
-    case DolphinView::SortBySize:
-        action = actionCollection()->action("sort_by_size");
-        break;
-    case DolphinView::SortByDate:
-        action = actionCollection()->action("sort_by_date");
-        break;
-    case DolphinView::SortByPermissions:
-        action = actionCollection()->action("sort_by_permissions");
-        break;
-    case DolphinView::SortByOwner:
-        action = actionCollection()->action("sort_by_owner");
-        break;
-    case DolphinView::SortByGroup:
-        action = actionCollection()->action("sort_by_group");
-        break;
-    case DolphinView::SortByType:
-        action = actionCollection()->action("sort_by_type");
-        break;
-#ifdef HAVE_NEPOMUK
-    case DolphinView::SortByRating:
-        action = actionCollection()->action("sort_by_rating");
-        break;
-    case DolphinView::SortByTags:
-        action = actionCollection()->action("sort_by_tags");
-        break;
-#endif
-    default:
-        break;
-    }
-
-    if (action != 0) {
-        KToggleAction* toggleAction = static_cast<KToggleAction*>(action);
-        toggleAction->setChecked(true);
-    }
-}
-
-void DolphinMainWindow::slotSortOrderChanged(Qt::SortOrder order)
-{
-    KToggleAction* descending = static_cast<KToggleAction*>(actionCollection()->action("descending"));
-    const bool sortDescending = (order == Qt::DescendingOrder);
-    descending->setChecked(sortDescending);
-}
-
-void DolphinMainWindow::slotAdditionalInfoChanged(KFileItemDelegate::InformationList list)
-{
-    QAction* showSizeInfo = actionCollection()->action("show_size_info");
-    QAction* showDateInfo = actionCollection()->action("show_date_info");
-    QAction* showPermissionsInfo = actionCollection()->action("show_permissions_info");
-    QAction* showOwnerInfo = actionCollection()->action("show_owner_info");
-    QAction* showGroupInfo = actionCollection()->action("show_group_info");
-    QAction* showMimeInfo = actionCollection()->action("show_mime_info");
-
-    showSizeInfo->setChecked(false);
-    showDateInfo->setChecked(false);
-    showPermissionsInfo->setChecked(false);
-    showOwnerInfo->setChecked(false);
-    showGroupInfo->setChecked(false);
-    showMimeInfo->setChecked(false);
-
-    const DolphinView* view = m_activeViewContainer->view();
-
-    const IconsModeSettings* settings = DolphinSettings::instance().iconsModeSettings();
-    const bool enable = (view->mode() == DolphinView::DetailsView) ||
-                         ((view->mode() == DolphinView::IconsView) && settings->showAdditionalInfo());
-
-    showSizeInfo->setEnabled(enable);
-    showDateInfo->setEnabled(enable);
-    showPermissionsInfo->setEnabled(enable);
-    showOwnerInfo->setEnabled(enable);
-    showGroupInfo->setEnabled(enable);
-    showMimeInfo->setEnabled(enable);
-
-    foreach (KFileItemDelegate::Information info, list) {
-        switch (info) {
-        case KFileItemDelegate::Size:
-            showSizeInfo->setChecked(true);
-            break;
-        case KFileItemDelegate::ModificationTime:
-            showDateInfo->setChecked(true);
-            break;
-        case KFileItemDelegate::Permissions:
-            showPermissionsInfo->setChecked(true);
-            break;
-        case KFileItemDelegate::Owner:
-            showOwnerInfo->setChecked(true);
-            break;
-        case KFileItemDelegate::OwnerAndGroup:
-            showGroupInfo->setChecked(true);
-            break;
-        case KFileItemDelegate::FriendlyMimeType:
-            showMimeInfo->setChecked(true);
-            break;
-        default:
-            break;
-        }
-    }
-}
-
 void DolphinMainWindow::slotSelectionChanged(const KFileItemList& selection)
 {
     updateEditActions();
@@ -345,8 +212,7 @@ void DolphinMainWindow::slotHistoryChanged()
 
 void DolphinMainWindow::updateFilterBarAction(bool show)
 {
-    KToggleAction* showFilterBarAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_filter_bar"));
+    QAction* showFilterBarAction = actionCollection()->action("show_filter_bar");
     showFilterBarAction->setChecked(show);
 }
 
@@ -429,31 +295,6 @@ void DolphinMainWindow::updateNewMenu()
     m_newMenu->setPopupFiles(activeViewContainer()->url());
 }
 
-void DolphinMainWindow::rename()
-{
-    clearStatusBar();
-    m_activeViewContainer->view()->renameSelectedItems();
-}
-
-void DolphinMainWindow::moveToTrash()
-{
-    clearStatusBar();
-
-    DolphinView* view = m_activeViewContainer->view();
-
-    if (QApplication::keyboardModifiers() & Qt::ShiftModifier) {
-        view->deleteSelectedItems();
-    } else {
-        view->trashSelectedItems();
-    }
-}
-
-void DolphinMainWindow::deleteItems()
-{
-    clearStatusBar();
-    m_activeViewContainer->view()->deleteSelectedItems();
-}
-
 void DolphinMainWindow::properties()
 {
     const KFileItemList list = m_activeViewContainer->view()->selectedItems();
@@ -587,107 +428,6 @@ void DolphinMainWindow::invertSelection()
     m_activeViewContainer->view()->invertSelection();
 }
 
-void DolphinMainWindow::setViewMode(QAction* action)
-{
-    const DolphinView::Mode mode = action->data().value<DolphinView::Mode>();
-    m_activeViewContainer->view()->setMode(mode);
-}
-
-void DolphinMainWindow::sortByName()
-{
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByName);
-}
-
-void DolphinMainWindow::sortBySize()
-{
-    m_activeViewContainer->view()->setSorting(DolphinView::SortBySize);
-}
-
-void DolphinMainWindow::sortByDate()
-{
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByDate);
-}
-
-void DolphinMainWindow::sortByPermissions()
-{
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByPermissions);
-}
-
-void DolphinMainWindow::sortByOwner()
-{
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByOwner);
-}
-
-void DolphinMainWindow::sortByGroup()
-{
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByGroup);
-}
-
-void DolphinMainWindow::sortByType()
-{
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByType);
-}
-
-void DolphinMainWindow::sortByRating()
-{
-#ifdef HAVE_NEPOMUK
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByRating);
-#endif
-}
-
-void DolphinMainWindow::sortByTags()
-{
-#ifdef HAVE_NEPOMUK
-    m_activeViewContainer->view()->setSorting(DolphinView::SortByTags);
-#endif
-}
-
-void DolphinMainWindow::toggleSortOrder()
-{
-    DolphinView* view = m_activeViewContainer->view();
-    const Qt::SortOrder order = (view->sortOrder() == Qt::AscendingOrder) ?
-                                Qt::DescendingOrder :
-                                Qt::AscendingOrder;
-    view->setSortOrder(order);
-}
-
-void DolphinMainWindow::toggleSortCategorization()
-{
-    DolphinView* view = m_activeViewContainer->view();
-    const bool categorizedSorting = view->categorizedSorting();
-    view->setCategorizedSorting(!categorizedSorting);
-}
-
-void DolphinMainWindow::toggleSizeInfo()
-{
-    toggleAdditionalInfo("show_size_info", KFileItemDelegate::Size);
-}
-
-void DolphinMainWindow::toggleDateInfo()
-{
-    toggleAdditionalInfo("show_date_info", KFileItemDelegate::ModificationTime);
-}
-
-void DolphinMainWindow::togglePermissionsInfo()
-{
-    toggleAdditionalInfo("show_permissions_info", KFileItemDelegate::Permissions);
-}
-
-void DolphinMainWindow::toggleOwnerInfo()
-{
-    toggleAdditionalInfo("show_owner_info", KFileItemDelegate::Owner);
-}
-
-void DolphinMainWindow::toggleGroupInfo()
-{
-    toggleAdditionalInfo("show_group_info", KFileItemDelegate::OwnerAndGroup);
-}
-
-void DolphinMainWindow::toggleMimeInfo()
-{
-    toggleAdditionalInfo("show_mime_info", KFileItemDelegate::FriendlyMimeType);
-}
-
 void DolphinMainWindow::toggleSplitView()
 {
     if (m_viewContainer[SecondaryView] == 0) {
@@ -720,7 +460,7 @@ void DolphinMainWindow::toggleSplitView()
 
     setActiveViewContainer(m_viewContainer[PrimaryView]);
     updateViewActions();
-    emit activeViewChanged();
+    emit activeViewChanged(); // TODO unused; remove?
 }
 
 void DolphinMainWindow::reloadView()
@@ -733,55 +473,18 @@ void DolphinMainWindow::stopLoading()
 {
 }
 
-void DolphinMainWindow::togglePreview()
+void DolphinMainWindow::toggleFilterBarVisibility(bool show)
 {
-    clearStatusBar();
-
-    const KToggleAction* showPreviewAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_preview"));
-    const bool show = showPreviewAction->isChecked();
-    m_activeViewContainer->view()->setShowPreview(show);
-}
-
-void DolphinMainWindow::toggleShowHiddenFiles()
-{
-    clearStatusBar();
-
-    const KToggleAction* showHiddenFilesAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_hidden_files"));
-    const bool show = showHiddenFilesAction->isChecked();
-    m_activeViewContainer->view()->setShowHiddenFiles(show);
-}
-
-void DolphinMainWindow::toggleFilterBarVisibility()
-{
-    const KToggleAction* showFilterBarAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_filter_bar"));
-    const bool show = showFilterBarAction->isChecked();
     m_activeViewContainer->showFilterBar(show);
 }
 
-void DolphinMainWindow::zoomIn()
-{
-    m_activeViewContainer->view()->zoomIn();
-    updateViewActions();
-}
-
-void DolphinMainWindow::zoomOut()
-{
-    m_activeViewContainer->view()->zoomOut();
-    updateViewActions();
-}
-
 void DolphinMainWindow::toggleEditLocation()
 {
     clearStatusBar();
 
-    KToggleAction* action = static_cast<KToggleAction*>(actionCollection()->action("editable_location"));
-
-    bool editOrBrowse = action->isChecked();
+    QAction* action = actionCollection()->action("editable_location");
     KUrlNavigator* urlNavigator = m_activeViewContainer->urlNavigator();
-    urlNavigator->setUrlEditable(editOrBrowse);
+    urlNavigator->setUrlEditable(action->isChecked());
 }
 
 void DolphinMainWindow::editLocation()
@@ -914,6 +617,8 @@ void DolphinMainWindow::init()
 
     const KUrl& homeUrl = settings.generalSettings()->homeUrl();
     setCaption(homeUrl.fileName());
+    m_actionHandler = new DolphinViewActionHandler(actionCollection(), this);
+    connect(m_actionHandler, SIGNAL(actionBeingHandled()), SLOT(clearStatusBar()));
     ViewProperties props(homeUrl);
     m_viewContainer[PrimaryView] = new DolphinViewContainer(this,
                                                             m_splitter,
@@ -921,8 +626,10 @@ void DolphinMainWindow::init()
 
     m_activeViewContainer = m_viewContainer[PrimaryView];
     connectViewSignals(PrimaryView);
-    m_viewContainer[PrimaryView]->view()->reload();
+    DolphinView* view = m_viewContainer[PrimaryView]->view();
+    view->reload();
     m_viewContainer[PrimaryView]->show();
+    m_actionHandler->setCurrentView(view);
 
     setCentralWidget(m_splitter);
     setupDockWidgets();
@@ -952,18 +659,20 @@ void DolphinMainWindow::init()
     emit urlChanged(homeUrl);
 }
 
-void DolphinMainWindow::setActiveViewContainer(DolphinViewContainer* view)
+void DolphinMainWindow::setActiveViewContainer(DolphinViewContainer* viewContainer)
 {
-    Q_ASSERT(view != 0);
-    Q_ASSERT((view == m_viewContainer[PrimaryView]) || (view == m_viewContainer[SecondaryView]));
-    if (m_activeViewContainer == view) {
+    Q_ASSERT(viewContainer != 0);
+    Q_ASSERT((viewContainer == m_viewContainer[PrimaryView]) || (viewContainer == m_viewContainer[SecondaryView]));
+    if (m_activeViewContainer == viewContainer) {
         return;
     }
 
     m_activeViewContainer->setActive(false);
-    m_activeViewContainer = view;
+    m_activeViewContainer = viewContainer;
     m_activeViewContainer->setActive(true);
 
+    m_actionHandler->setCurrentView(viewContainer->view());
+
     updateHistory();
     updateEditActions();
     updateViewActions();
@@ -972,7 +681,7 @@ void DolphinMainWindow::setActiveViewContainer(DolphinViewContainer* view)
     const KUrl& url = m_activeViewContainer->url();
     setCaption(url.fileName());
 
-    emit activeViewChanged();
+    emit activeViewChanged(); // TODO unused; remove?
     emit urlChanged(url);
 }
 
@@ -992,15 +701,6 @@ void DolphinMainWindow::setupActions()
     newWindow->setShortcut(Qt::CTRL | Qt::Key_N);
     connect(newWindow, SIGNAL(triggered()), this, SLOT(openNewMainWindow()));
 
-    KAction* rename = DolphinView::createRenameAction(actionCollection());
-    connect(rename, SIGNAL(triggered()), this, SLOT(rename()));
-
-    KAction* moveToTrash = DolphinView::createMoveToTrashAction(actionCollection());
-    connect(moveToTrash, SIGNAL(triggered()), this, SLOT(moveToTrash()));
-
-    KAction* deleteAction = DolphinView::createDeleteAction(actionCollection());
-    connect(deleteAction, SIGNAL(triggered()), this, SLOT(deleteItems()));
-
     KAction* properties = actionCollection()->addAction("properties");
     properties->setText(i18nc("@action:inmenu File", "Properties"));
     properties->setShortcut(Qt::ALT | Qt::Key_Return);
@@ -1033,134 +733,10 @@ void DolphinMainWindow::setupActions()
     connect(invertSelection, SIGNAL(triggered()), this, SLOT(invertSelection()));
 
     // setup 'View' menu
-    KStandardAction::zoomIn(this,
-                            SLOT(zoomIn()),
-                            actionCollection());
-
-    KStandardAction::zoomOut(this,
-                             SLOT(zoomOut()),
-                             actionCollection());
-
-
-    KToggleAction* iconsView = DolphinView::iconsModeAction(actionCollection());
-    KToggleAction* detailsView = DolphinView::detailsModeAction(actionCollection());
-    KToggleAction* columnView = DolphinView::columnsModeAction(actionCollection());
-
-    QActionGroup* viewModeGroup = new QActionGroup(this);
-    viewModeGroup->addAction(iconsView);
-    viewModeGroup->addAction(detailsView);
-    viewModeGroup->addAction(columnView);
-    connect(viewModeGroup, SIGNAL(triggered(QAction*)), this, SLOT(setViewMode(QAction*)));
-
-    KToggleAction* sortByName = actionCollection()->add<KToggleAction>("sort_by_name");
-    sortByName->setText(i18nc("@action:inmenu Sort By", "Name"));
-    connect(sortByName, SIGNAL(triggered()), this, SLOT(sortByName()));
-
-    KToggleAction* sortBySize = actionCollection()->add<KToggleAction>("sort_by_size");
-    sortBySize->setText(i18nc("@action:inmenu Sort By", "Size"));
-    connect(sortBySize, SIGNAL(triggered()), this, SLOT(sortBySize()));
-
-    KToggleAction* sortByDate = actionCollection()->add<KToggleAction>("sort_by_date");
-    sortByDate->setText(i18nc("@action:inmenu Sort By", "Date"));
-    connect(sortByDate, SIGNAL(triggered()), this, SLOT(sortByDate()));
-
-    KToggleAction* sortByPermissions = actionCollection()->add<KToggleAction>("sort_by_permissions");
-    sortByPermissions->setText(i18nc("@action:inmenu Sort By", "Permissions"));
-    connect(sortByPermissions, SIGNAL(triggered()), this, SLOT(sortByPermissions()));
-
-    KToggleAction* sortByOwner = actionCollection()->add<KToggleAction>("sort_by_owner");
-    sortByOwner->setText(i18nc("@action:inmenu Sort By", "Owner"));
-    connect(sortByOwner, SIGNAL(triggered()), this, SLOT(sortByOwner()));
-
-    KToggleAction* sortByGroup = actionCollection()->add<KToggleAction>("sort_by_group");
-    sortByGroup->setText(i18nc("@action:inmenu Sort By", "Group"));
-    connect(sortByGroup, SIGNAL(triggered()), this, SLOT(sortByGroup()));
-
-    KToggleAction* sortByType = actionCollection()->add<KToggleAction>("sort_by_type");
-    sortByType->setText(i18nc("@action:inmenu Sort By", "Type"));
-    connect(sortByType, SIGNAL(triggered()), this, SLOT(sortByType()));
-
-    // TODO: Hided "sort by rating" and "sort by tags" as without caching the performance
-    // is too slow currently (Nepomuk will support caching in future releases).
-    //
-    // KToggleAction* sortByRating = actionCollection()->add<KToggleAction>("sort_by_rating");
-    // sortByRating->setText(i18nc("@action:inmenu Sort By", "Rating"));
-    //
-    // KToggleAction* sortByTags = actionCollection()->add<KToggleAction>("sort_by_tags");
-    // sortByTags->setText(i18nc("@action:inmenu Sort By", "Tags"));
-    //
-#ifdef HAVE_NEPOMUK
-    // if (MetaDataWidget::metaDataAvailable()) {
-    //     connect(sortByRating, SIGNAL(triggered()), this, SLOT(sortByRating()));
-    //     connect(sortByTags, SIGNAL(triggered()), this, SLOT(sortByTags()));
-    // }
-    // else {
-    //     sortByRating->setEnabled(false);
-    //     sortByTags->setEnabled(false);
-    // }
-#else
-    // sortByRating->setEnabled(false);
-    // sortByTags->setEnabled(false);
-#endif
-
-    QActionGroup* sortGroup = new QActionGroup(this);
-    sortGroup->addAction(sortByName);
-    sortGroup->addAction(sortBySize);
-    sortGroup->addAction(sortByDate);
-    sortGroup->addAction(sortByPermissions);
-    sortGroup->addAction(sortByOwner);
-    sortGroup->addAction(sortByGroup);
-    sortGroup->addAction(sortByType);
-
-    // TODO: Hided "sort by rating" and "sort by tags" as without caching the performance
-    // is too slow currently (Nepomuk will support caching in future releases).
-    //sortGroup->addAction(sortByRating);
-    //sortGroup->addAction(sortByTags);
-
-    KToggleAction* sortDescending = actionCollection()->add<KToggleAction>("descending");
-    sortDescending->setText(i18nc("@action:inmenu Sort", "Descending"));
-    connect(sortDescending, SIGNAL(triggered()), this, SLOT(toggleSortOrder()));
-
-    KToggleAction* showInGroups = actionCollection()->add<KToggleAction>("show_in_groups");
-    showInGroups->setText(i18nc("@action:inmenu View", "Show in Groups"));
-    connect(showInGroups, SIGNAL(triggered()), this, SLOT(toggleSortCategorization()));
-
-    KToggleAction* showSizeInfo = actionCollection()->add<KToggleAction>("show_size_info");
-    showSizeInfo->setText(i18nc("@action:inmenu Additional information", "Size"));
-    connect(showSizeInfo, SIGNAL(triggered()), this, SLOT(toggleSizeInfo()));
-
-    KToggleAction* showDateInfo = actionCollection()->add<KToggleAction>("show_date_info");
-    showDateInfo->setText(i18nc("@action:inmenu Additional information", "Date"));
-    connect(showDateInfo, SIGNAL(triggered()), this, SLOT(toggleDateInfo()));
-
-    KToggleAction* showPermissionsInfo = actionCollection()->add<KToggleAction>("show_permissions_info");
-    showPermissionsInfo->setText(i18nc("@action:inmenu Additional information", "Permissions"));
-    connect(showPermissionsInfo, SIGNAL(triggered()), this, SLOT(togglePermissionsInfo()));
-
-    KToggleAction* showOwnerInfo = actionCollection()->add<KToggleAction>("show_owner_info");
-    showOwnerInfo->setText(i18nc("@action:inmenu Additional information", "Owner"));
-    connect(showOwnerInfo, SIGNAL(triggered()), this, SLOT(toggleOwnerInfo()));
-
-    KToggleAction* showGroupInfo = actionCollection()->add<KToggleAction>("show_group_info");
-    showGroupInfo->setText(i18nc("@action:inmenu Additional information", "Group"));
-    connect(showGroupInfo, SIGNAL(triggered()), this, SLOT(toggleGroupInfo()));
-
-    KToggleAction* showMimeInfo = actionCollection()->add<KToggleAction>("show_mime_info");
-    showMimeInfo->setText(i18nc("@action:inmenu Additional information", "Type"));
-    connect(showMimeInfo, SIGNAL(triggered()), this, SLOT(toggleMimeInfo()));
-
-    KToggleAction* showPreview = actionCollection()->add<KToggleAction>("show_preview");
-    showPreview->setText(i18nc("@action:intoolbar", "Preview"));
-    showPreview->setIcon(KIcon("view-preview"));
-    connect(showPreview, SIGNAL(triggered()), this, SLOT(togglePreview()));
-
-    KToggleAction* showHiddenFiles = actionCollection()->add<KToggleAction>("show_hidden_files");
-    showHiddenFiles->setText(i18nc("@action:inmenu View", "Show Hidden Files"));
-    showHiddenFiles->setShortcut(Qt::ALT | Qt::Key_Period);
-    connect(showHiddenFiles, SIGNAL(triggered()), this, SLOT(toggleShowHiddenFiles()));
+    // (note that most of it is set up in DolphinViewActionHandler)
 
     KAction* split = actionCollection()->addAction("split_view");
-    split->setShortcut(Qt::Key_F10);
+    split->setShortcut(Qt::Key_F3);
     updateSplitAction();
     connect(split, SIGNAL(triggered()), this, SLOT(toggleSplitView()));
 
@@ -1212,7 +788,7 @@ void DolphinMainWindow::setupActions()
     KToggleAction* showFilterBar = actionCollection()->add<KToggleAction>("show_filter_bar");
     showFilterBar->setText(i18nc("@action:inmenu Tools", "Show Filter Bar"));
     showFilterBar->setShortcut(Qt::CTRL | Qt::Key_I);
-    connect(showFilterBar, SIGNAL(triggered()), this, SLOT(toggleFilterBarVisibility()));
+    connect(showFilterBar, SIGNAL(triggered(bool)), this, SLOT(toggleFilterBarVisibility(bool)));
 
     KAction* compareFiles = actionCollection()->addAction("compare_files");
     compareFiles->setText(i18nc("@action:inmenu Tools", "Compare Files"));
@@ -1360,44 +936,14 @@ void DolphinMainWindow::updateEditActions()
 
 void DolphinMainWindow::updateViewActions()
 {
-    const DolphinView* view = m_activeViewContainer->view();
-    QAction* zoomInAction = actionCollection()->action(KStandardAction::stdName(KStandardAction::ZoomIn));
-    if (zoomInAction != 0) {
-        zoomInAction->setEnabled(view->isZoomInPossible());
-    }
+    m_actionHandler->updateViewActions();
 
-    QAction* zoomOutAction = actionCollection()->action(KStandardAction::stdName(KStandardAction::ZoomOut));
-    if (zoomOutAction != 0) {
-        zoomOutAction->setEnabled(view->isZoomOutPossible());
-    }
-
-    QAction* action = actionCollection()->action(view->currentViewModeActionName());
-    if (action != 0) {
-        KToggleAction* toggleAction = static_cast<KToggleAction*>(action);
-        toggleAction->setChecked(true);
-    }
-
-    slotSortingChanged(view->sorting());
-    slotSortOrderChanged(view->sortOrder());
-    slotCategorizedSortingChanged();
-    slotAdditionalInfoChanged(view->additionalInfo());
-
-    KToggleAction* showFilterBarAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_filter_bar"));
+    QAction* showFilterBarAction = actionCollection()->action("show_filter_bar");
     showFilterBarAction->setChecked(m_activeViewContainer->isFilterBarVisible());
 
-    KToggleAction* showPreviewAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_preview"));
-    showPreviewAction->setChecked(view->showPreview());
-
-    KToggleAction* showHiddenFilesAction =
-        static_cast<KToggleAction*>(actionCollection()->action("show_hidden_files"));
-    showHiddenFilesAction->setChecked(view->showHiddenFiles());
-
     updateSplitAction();
 
-    KToggleAction* editableLocactionAction =
-        static_cast<KToggleAction*>(actionCollection()->action("editable_location"));
+    QAction* editableLocactionAction = actionCollection()->action("editable_location");
     const KUrlNavigator* urlNavigator = m_activeViewContainer->urlNavigator();
     editableLocactionAction->setChecked(urlNavigator->isUrlEditable());
 }
@@ -1421,20 +967,6 @@ void DolphinMainWindow::connectViewSignals(int viewIndex)
             this, SLOT(updateFilterBarAction(bool)));
 
     DolphinView* view = container->view();
-    connect(view, SIGNAL(modeChanged()),
-            this, SLOT(slotViewModeChanged()));
-    connect(view, SIGNAL(showPreviewChanged()),
-            this, SLOT(slotShowPreviewChanged()));
-    connect(view, SIGNAL(showHiddenFilesChanged()),
-            this, SLOT(slotShowHiddenFilesChanged()));
-    connect(view, SIGNAL(categorizedSortingChanged()),
-            this, SLOT(slotCategorizedSortingChanged()));
-    connect(view, SIGNAL(sortingChanged(DolphinView::Sorting)),
-            this, SLOT(slotSortingChanged(DolphinView::Sorting)));
-    connect(view, SIGNAL(sortOrderChanged(Qt::SortOrder)),
-            this, SLOT(slotSortOrderChanged(Qt::SortOrder)));
-    connect(view, SIGNAL(additionalInfoChanged(KFileItemDelegate::InformationList)),
-            this, SLOT(slotAdditionalInfoChanged(KFileItemDelegate::InformationList)));
     connect(view, SIGNAL(selectionChanged(KFileItemList)),
             this, SLOT(slotSelectionChanged(KFileItemList)));
     connect(view, SIGNAL(requestItemInfo(KFileItem)),
@@ -1468,28 +1000,6 @@ void DolphinMainWindow::updateSplitAction()
     }
 }
 
-void DolphinMainWindow::toggleAdditionalInfo(const char* actionName,
-                                             KFileItemDelegate::Information info)
-{
-    clearStatusBar();
-
-    DolphinView* view = m_activeViewContainer->view();
-    KFileItemDelegate::InformationList list = view->additionalInfo();
-
-    const bool show = actionCollection()->action(actionName)->isChecked();
-
-    const int index = list.indexOf(info);
-    const bool containsInfo = (index >= 0);
-    if (show && !containsInfo) {
-        list.append(info);
-        view->setAdditionalInfo(list);
-    } else if (!show && containsInfo) {
-        list.removeAt(index);
-        view->setAdditionalInfo(list);
-        Q_ASSERT(list.indexOf(info) < 0);
-    }
-}
-
 DolphinMainWindow::UndoUiInterface::UndoUiInterface(DolphinMainWindow* mainWin) :
     KonqFileUndoManager::UiInterface(mainWin),
     m_mainWin(mainWin)
