@@ -19,8 +19,6 @@
  ***************************************************************************/
 
 #include "dolphinview.h"
-#include <ktoggleaction.h>
-#include <kactioncollection.h>
 
 #include <QApplication>
 #include <QClipboard>
@@ -30,6 +28,7 @@
 #include <QTimer>
 #include <QScrollBar>
 
+#include <kactioncollection.h>
 #include <kcolorscheme.h>
 #include <kdirlister.h>
 #include <kfileitemdelegate.h>
@@ -43,6 +42,7 @@
 #include <kmimetyperesolver.h>
 #include <konqmimedata.h>
 #include <konq_operations.h>
+#include <ktoggleaction.h>
 #include <kurl.h>
 
 #include "dolphindropcontroller.h"
@@ -206,9 +206,6 @@ void DolphinView::setMode(Mode mode)
 
     deleteView();
 
-    // It is important to read the view properties _after_ deleting the view,
-    // as e. g. the detail view might adjust the additional information properties
-    // after getting closed:
     const KUrl viewPropsUrl = viewPropertiesUrl();
     ViewProperties props(viewPropsUrl);
     props.setViewMode(m_mode);
@@ -218,7 +215,7 @@ void DolphinView::setMode(Mode mode)
     // additional information manually
     const KFileItemDelegate::InformationList infoList = props.additionalInfo();
     m_fileItemDelegate->setShowInformation(infoList);
-    emit additionalInfoChanged(infoList);
+    emit additionalInfoChanged();
 
     // Not all view modes support categorized sorting. Adjust the sorting model
     // if changing the view mode results in a change of the categorized sorting
@@ -470,7 +467,7 @@ void DolphinView::setAdditionalInfo(KFileItemDelegate::InformationList info)
     props.setAdditionalInfo(info);
     m_fileItemDelegate->setShowInformation(info);
 
-    emit additionalInfoChanged(info);
+    emit additionalInfoChanged();
 
     if (itemView() != m_detailsView) {
         // the details view requires no reloading of the directory, as it maps
@@ -711,7 +708,7 @@ void DolphinView::applyViewProperties(const KUrl& url)
     KFileItemDelegate::InformationList info = props.additionalInfo();
     if (info != m_fileItemDelegate->showInformation()) {
         m_fileItemDelegate->setShowInformation(info);
-        emit additionalInfoChanged(info);
+        emit additionalInfoChanged();
     }
 
     const bool showPreview = props.showPreview();
@@ -797,6 +794,14 @@ void DolphinView::updateSortOrder(Qt::SortOrder order)
     emit sortOrderChanged(order);
 }
 
+void DolphinView::toggleSortOrder()
+{
+    const Qt::SortOrder order = (sortOrder() == Qt::AscendingOrder) ?
+                                Qt::DescendingOrder :
+                                Qt::AscendingOrder;
+    setSortOrder(order);
+}
+
 void DolphinView::updateAdditionalInfo(const KFileItemDelegate::InformationList& info)
 {
     ViewProperties props(viewPropertiesUrl());
@@ -805,8 +810,80 @@ void DolphinView::updateAdditionalInfo(const KFileItemDelegate::InformationList&
 
     m_fileItemDelegate->setShowInformation(info);
 
-    emit additionalInfoChanged(info);
+    emit additionalInfoChanged();
+}
 
+void DolphinView::updateAdditionalInfoActions(KActionCollection* collection)
+{
+    const bool enable = (m_mode == DolphinView::DetailsView) ||
+                        (m_mode == DolphinView::IconsView);
+
+    QAction* showSizeInfo = collection->action("show_size_info");
+    QAction* showDateInfo = collection->action("show_date_info");
+    QAction* showPermissionsInfo = collection->action("show_permissions_info");
+    QAction* showOwnerInfo = collection->action("show_owner_info");
+    QAction* showGroupInfo = collection->action("show_group_info");
+    QAction* showMimeInfo = collection->action("show_mime_info");
+
+    showSizeInfo->setChecked(false);
+    showDateInfo->setChecked(false);
+    showPermissionsInfo->setChecked(false);
+    showOwnerInfo->setChecked(false);
+    showGroupInfo->setChecked(false);
+    showMimeInfo->setChecked(false);
+
+    showSizeInfo->setEnabled(enable);
+    showDateInfo->setEnabled(enable);
+    showPermissionsInfo->setEnabled(enable);
+    showOwnerInfo->setEnabled(enable);
+    showGroupInfo->setEnabled(enable);
+    showMimeInfo->setEnabled(enable);
+
+    foreach (KFileItemDelegate::Information info, m_fileItemDelegate->showInformation()) {
+        switch (info) {
+        case KFileItemDelegate::Size:
+            showSizeInfo->setChecked(true);
+            break;
+        case KFileItemDelegate::ModificationTime:
+            showDateInfo->setChecked(true);
+            break;
+        case KFileItemDelegate::Permissions:
+            showPermissionsInfo->setChecked(true);
+            break;
+        case KFileItemDelegate::Owner:
+            showOwnerInfo->setChecked(true);
+            break;
+        case KFileItemDelegate::OwnerAndGroup:
+            showGroupInfo->setChecked(true);
+            break;
+        case KFileItemDelegate::FriendlyMimeType:
+            showMimeInfo->setChecked(true);
+            break;
+        default:
+            break;
+        }
+    }
+}
+
+void DolphinView::toggleAdditionalInfo(QAction* action)
+{
+    const KFileItemDelegate::Information info =
+        static_cast<KFileItemDelegate::Information>(action->data().toInt());
+
+    KFileItemDelegate::InformationList list = additionalInfo();
+
+    const bool show = action->isChecked();
+
+    const int index = list.indexOf(info);
+    const bool containsInfo = (index >= 0);
+    if (show && !containsInfo) {
+        list.append(info);
+        setAdditionalInfo(list);
+    } else if (!show && containsInfo) {
+        list.removeAt(index);
+        setAdditionalInfo(list);
+        Q_ASSERT(list.indexOf(info) < 0);
+    }
 }
 
 void DolphinView::emitContentsMoved()
@@ -993,49 +1070,6 @@ void DolphinView::applyCutItemEffect()
     }
 }
 
-KToggleAction* DolphinView::iconsModeAction(KActionCollection* actionCollection)
-{
-    KToggleAction* iconsView = actionCollection->add<KToggleAction>("icons");
-    iconsView->setText(i18nc("@action:inmenu View Mode", "Icons"));
-    iconsView->setShortcut(Qt::CTRL | Qt::Key_1);
-    iconsView->setIcon(KIcon("view-list-icons"));
-    iconsView->setData(QVariant::fromValue(IconsView));
-    return iconsView;
-}
-
-KToggleAction* DolphinView::detailsModeAction(KActionCollection* actionCollection)
-{
-    KToggleAction* detailsView = actionCollection->add<KToggleAction>("details");
-    detailsView->setText(i18nc("@action:inmenu View Mode", "Details"));
-    detailsView->setShortcut(Qt::CTRL | Qt::Key_2);
-    detailsView->setIcon(KIcon("view-list-details"));
-    detailsView->setData(QVariant::fromValue(DetailsView));
-    return detailsView;
-}
-
-KToggleAction* DolphinView::columnsModeAction(KActionCollection* actionCollection)
-{
-    KToggleAction* columnView = actionCollection->add<KToggleAction>("columns");
-    columnView->setText(i18nc("@action:inmenu View Mode", "Columns"));
-    columnView->setShortcut(Qt::CTRL | Qt::Key_3);
-    columnView->setIcon(KIcon("view-file-columns"));
-    columnView->setData(QVariant::fromValue(ColumnView));
-    return columnView;
-}
-
-QString DolphinView::currentViewModeActionName() const
-{
-    switch (m_mode) {
-    case DolphinView::IconsView:
-        return "icons";
-    case DolphinView::DetailsView:
-        return "details";
-    case DolphinView::ColumnView:
-        return "columns";
-    }
-    return QString(); // can't happen
-}
-
 void DolphinView::renameSelectedItems()
 {
     const KFileItemList items = selectedItems();
@@ -1224,30 +1258,4 @@ QPair<bool, QString> DolphinView::pasteInfo() const
     return ret;
 }
 
-KAction* DolphinView::createRenameAction(KActionCollection* collection)
-{
-    KAction* rename = collection->addAction("rename");
-    rename->setText(i18nc("@action:inmenu File", "Rename..."));
-    rename->setShortcut(Qt::Key_F2);
-    return rename;
-}
-
-KAction* DolphinView::createMoveToTrashAction(KActionCollection* collection)
-{
-    KAction* moveToTrash = collection->addAction("move_to_trash");
-    moveToTrash->setText(i18nc("@action:inmenu File", "Move to Trash"));
-    moveToTrash->setIcon(KIcon("user-trash"));
-    moveToTrash->setShortcut(QKeySequence::Delete);
-    return moveToTrash;
-}
-
-KAction* DolphinView::createDeleteAction(KActionCollection* collection)
-{
-    KAction* deleteAction = collection->addAction("delete");
-    deleteAction->setIcon(KIcon("edit-delete"));
-    deleteAction->setText(i18nc("@action:inmenu File", "Delete"));
-    deleteAction->setShortcut(Qt::SHIFT | Qt::Key_Delete);
-    return deleteAction;
-}
-
 #include "dolphinview.moc"
