@@ -38,8 +38,6 @@
 #include <QListView>
 #include <QWidget>
 
-class KAction;
-class KToggleAction;
 class DolphinController;
 class KDirLister;
 class KFileItemDelegate;
@@ -119,15 +117,15 @@ public:
     };
 
     /**
-     * @param parent          Parent widget of the view.
-     * @param url             Specifies the content which should be shown.
-     * @param dirLister       Used directory lister. The lister is not owned
-     *                        by the view and won't get deleted.
-     * @param dolphinModel    Used directory model. The model is not owned
-     *                        by the view and won't get deleted.
-     * @param proxyModel      Used proxy model which specifies the sorting. The
-     *                        model is not owned by the view and won't get
-     *                        deleted.
+     * @param parent           Parent widget of the view.
+     * @param url              Specifies the content which should be shown.
+     * @param dirLister        Used directory lister. The lister is not owned
+     *                         by the view and won't get deleted.
+     * @param dolphinModel     Used directory model. The model is not owned
+     *                         by the view and won't get deleted.
+     * @param proxyModel       Used proxy model which specifies the sorting. The
+     *                         model is not owned by the view and won't get
+     *                         deleted.
      */
     DolphinView(QWidget* parent,
                 const KUrl& url,
@@ -165,39 +163,18 @@ public:
      * Changes the view mode for the current directory to \a mode.
      * If the view properties should be remembered for each directory
      * (GeneralSettings::globalViewProps() returns false), then the
-     * changed view mode will be be stored automatically.
+     * changed view mode will be stored automatically.
      */
     void setMode(Mode mode);
     Mode mode() const;
 
-    /**
-     * Turns on the file preview for the all files of the current directory,
-     * if \a show is true.
-     * If the view properties should be remembered for each directory
-     * (GeneralSettings::globalViewProps() returns false), then the
-     * preview setting will be be stored automatically.
-     */
-    void setShowPreview(bool show);
+    /** See setShowPreview */
     bool showPreview() const;
 
-    /**
-     * Shows all hidden files of the current directory,
-     * if \a show is true.
-     * If the view properties should be remembered for each directory
-     * (GeneralSettings::globalViewProps() returns false), then the
-     * show hidden file setting will be be stored automatically.
-     */
-    void setShowHiddenFiles(bool show);
+    /** See setShowHiddenFiles */
     bool showHiddenFiles() const;
 
-    /**
-     * Summarizes all sorted items by their category \a categorized
-     * is true.
-     * If the view properties should be remembered for each directory
-     * (GeneralSettings::globalViewProps() returns false), then the
-     * categorized sorting setting will be be stored automatically.
-     */
-    void setCategorizedSorting(bool categorized);
+    /** See setCategorizedSorting */
     bool categorizedSorting() const;
 
     /**
@@ -327,45 +304,9 @@ public:
     void calculateItemCount(int& fileCount, int& folderCount);
 
     /**
-     * Returns the "switch to icons mode" action.
-     * This code is here to share it between the mainwindow and the part
+     * Updates the state of the 'Additional Information' actions in \a collection.
      */
-    static KToggleAction* iconsModeAction(KActionCollection* collection);
-
-    /**
-     * Returns the "switch to details mode" action.
-     * This code is here to share it between the mainwindow and the part
-     */
-    static KToggleAction* detailsModeAction(KActionCollection* collection);
-
-    /**
-     * Returns the "switch to columns mode" action.
-     * This code is here to share it between the mainwindow and the part
-     */
-    static KToggleAction* columnsModeAction(KActionCollection* collection);
-
-    /**
-     * Creates the rename action.
-     * This code is here to share it between the mainwindow and the part
-     */
-    static KAction* createRenameAction(KActionCollection* collection);
-
-    /**
-     * Creates the "move to trash" action.
-     * This code is here to share it between the mainwindow and the part
-     */
-    static KAction* createMoveToTrashAction(KActionCollection* collection);
-
-    /**
-     * Creates the delete action.
-     * This code is here to share it between the mainwindow and the part
-     */
-    static KAction* createDeleteAction(KActionCollection* collection);
-
-    /**
-     * Returns the action name corresponding to the current view mode
-     */
-    QString currentViewModeActionName() const;
+    void updateAdditionalInfoActions(KActionCollection* collection);
 
     /**
      * Returns the state of the paste action:
@@ -417,6 +358,42 @@ public slots:
     /** Pastes the clipboard data to this view. */
     void paste();
 
+    /**
+     * Turns on the file preview for the all files of the current directory,
+     * if \a show is true.
+     * If the view properties should be remembered for each directory
+     * (GeneralSettings::globalViewProps() returns false), then the
+     * preview setting will be stored automatically.
+     */
+    void setShowPreview(bool show);
+
+    /**
+     * Shows all hidden files of the current directory,
+     * if \a show is true.
+     * If the view properties should be remembered for each directory
+     * (GeneralSettings::globalViewProps() returns false), then the
+     * show hidden file setting will be stored automatically.
+     */
+    void setShowHiddenFiles(bool show);
+
+    /**
+     * Summarizes all sorted items by their category \a categorized
+     * is true.
+     * If the view properties should be remembered for each directory
+     * (GeneralSettings::globalViewProps() returns false), then the
+     * categorized sorting setting will be stored automatically.
+     */
+    void setCategorizedSorting(bool categorized);
+
+    /** Switches between an ascending and descending sorting order. */
+    void toggleSortOrder();
+
+    /**
+     * Switches on or off the displaying of additional information
+     * as specified by \a action.
+     */
+    void toggleAdditionalInfo(QAction* action);
+
 signals:
     /**
      * Is emitted if the view has been activated by e. g. a mouse click.
@@ -452,8 +429,8 @@ signals:
     /** Is emitted if the sort order (ascending or descending) has been changed. */
     void sortOrderChanged(Qt::SortOrder order);
 
-    /** Is emitted if the additional information for an item has been changed. */
-    void additionalInfoChanged(const KFileItemDelegate::InformationList& info);
+    /** Is emitted if the additional information shown for this view has been changed. */
+    void additionalInfoChanged();
 
     /**
      * Is emitted if information of an item is requested to be shown e. g. in the sidebar.
