@@ -171,6 +171,9 @@ public:
   // Number of main views (non-toggle non-passive views)
   int mainViewsCount() const;
 
+    // Return true if we are showing a view that supports this mimeType.
+    bool hasViewWithMimeType(const QString& mimeType) const;
+
   typedef QMap<KParts::ReadOnlyPart *, KonqView *> MapViews;
 
   const MapViews & viewMap() const { return m_mapViews; }
@@ -218,7 +221,6 @@ public:
 
   void updateToolBarActions( bool pendingActions = false );
   void updateOpenWithActions();
-  void updateViewModeActions();
   void updateViewActions();
 
   bool sidebarVisible() const;
@@ -320,6 +322,10 @@ Q_SIGNALS:
   void popupItemsDisturbed();
 
 public Q_SLOTS:
+    void updateViewModeActions();
+
+    void slotInternalViewModeChanged();
+
     void slotCtrlTabPressed();
 
     void slotPopupMenu( const QPoint &global, const KFileItemList &items, const KParts::OpenUrlArguments &args, const KParts::BrowserArguments& browserArgs, KParts::BrowserExtension::PopupFlags flags, const KParts::BrowserExtension::ActionGroupMap& );
@@ -347,7 +353,7 @@ public Q_SLOTS:
   void slotOpenFile();
 
   // View menu
-  void slotViewModeToggle( bool toggle );
+  void slotViewModeTriggered(QAction* action);
   void slotShowHTML();
   void slotLockView();
   void slotLinkView();
@@ -507,8 +513,6 @@ protected:
 
   void applyKonqMainWindowSettings();
 
-  void saveToolBarServicesMap();
-
   void viewsChanged();
 
   void updateLocalPropsActions();
@@ -579,7 +583,6 @@ private:
 
   void plugViewModeActions();
   void unplugViewModeActions();
-  static QString viewModeActionKey( KService::Ptr service );
 
   bool stayPreloaded();
   bool checkPreloadResourceUsage();
@@ -636,7 +639,7 @@ private: // members
   KAction *m_paMoveTabRight;
 
   KAction *m_paConfigureExtensions;
-  //KAction *m_paConfigureSpellChecking;
+  KAction *m_paConfigureSpellChecking;
 
   KAnimatedButton *m_paAnimatedLogo;
 
@@ -657,7 +660,6 @@ private: // members
   bool m_bHTMLAllowed:1;
   // Set in constructor, used in slotRunFinished
   bool m_bNeedApplyKonqMainWindowSettings:1;
-  bool m_bViewModeToggled:1;
   bool m_urlCompletionStarted:1;
   bool m_prevMenuBarVisible:1;
 
@@ -701,13 +703,6 @@ private: // members
   QList<QAction *> m_openWithActions;
   KActionMenu *m_viewModeMenu;
   QActionGroup* m_viewModesGroup;
-  QList<QAction*> m_toolBarViewModeActions; // basically holds three KonqViewActions, one of
-                                              // iconview, one for listview, and one for externals
-  QActionGroup* m_toolBarViewModesGroup;
-  QList<KToggleAction *> m_viewModeActions;
-  QMap<QString,KService::Ptr> m_viewModeToolBarServices; // similar to m_toolBarViewModeActions
-  // it holds a map library name (libkonqiconview/libkonqlistview) ==> service (service for
-  // iconview, multicolumnview, treeview, etc .)
   QActionGroup* m_closedTabsGroup;
 
   static QList<KonqMainWindow*> *s_lstViews;
