@@ -1314,10 +1314,10 @@ void Screen::writeSelectionToStream(TerminalCharacterDecoder* decoder ,
 	for (int y=top;y<=bottom;y++)
 	{
 			int start = 0;
-			if ( y == top ) start = left;
+			if ( y == top || columnmode ) start = left;
 		
 			int count = -1;
-			if ( y == bottom) count = right - start + 1;
+			if ( y == bottom || columnmode ) count = right - start + 1;
 
             const bool appendNewLine = ( y != bottom );
 			copyLineToStream( y,
@@ -1395,7 +1395,7 @@ void Screen::copyLineToStream(int line ,
             }
 
             // count cannot be any greater than length
-            count = qMin(length,count);
+			count = qBound(0,count,length-start);
 
             Q_ASSERT( screenLine < lineProperties.count() );
             currentLineProperties |= lineProperties[screenLine]; 
