@@ -274,9 +274,12 @@ void Session::run()
   // Check to see if the given program is executable.
   QString exec = QFile::encodeName(_program);
 
-  // if 'exec' is not specified, fall back to shell
+  // if 'exec' is not specified, fall back to default shell.  if that 
+  // is not set then fall back to /bin/sh
   if ( exec.isEmpty() )
       exec = getenv("SHELL");
+  if ( exec.isEmpty() )
+  	  exec = "/bin/sh";
 
   // if no arguments are specified, fall back to shell
   QStringList arguments =  _arguments.join(QChar(' ')).isEmpty() ?
@@ -323,6 +326,8 @@ void Session::run()
   }
 
   _shellProcess->setWriteable(false);  // We are reachable via kwrited.
+
+  emit started();
 }
 
 void Session::setUserTitle( int what, const QString &caption )
