@@ -273,7 +273,6 @@ TerminalDisplay::TerminalDisplay(QWidget *parent)
 ,_isFixedSize(false)
 ,_possibleTripleClick(false)
 ,_resizeWidget(0)
-,_resizeLabel(0)
 ,_resizeTimer(0)
 ,_flowControlWarningEnabled(false)
 ,_outputSuspendedLabel(0)
@@ -283,6 +282,10 @@ TerminalDisplay::TerminalDisplay(QWidget *parent)
 ,_filterChain(new TerminalImageFilterChain())
 ,_cursorShape(BlockCursor)
 {
+  // terminal applications are not designed with Right-To-Left in mind,
+  // so the layout is forced to Left-To-Right
+  setLayoutDirection(Qt::LeftToRight);
+
   // The offsets are not yet calculated.
   // Do not calculate these too often to be more smoothly when resizing
   // konsole in opaque mode.
@@ -294,21 +297,22 @@ TerminalDisplay::TerminalDisplay(QWidget *parent)
   _scrollBar = new QScrollBar(this);
   setScroll(0,0); 
   _scrollBar->setCursor( Qt::ArrowCursor );
-  connect(_scrollBar, SIGNAL(valueChanged(int)), this, SLOT(scrollBarPositionChanged(int)));
+  connect(_scrollBar, SIGNAL(valueChanged(int)), this, 
+  					  SLOT(scrollBarPositionChanged(int)));
 
+  // setup timers for blinking cursor and text
   _blinkTimer   = new QTimer(this);
   connect(_blinkTimer, SIGNAL(timeout()), this, SLOT(blinkEvent()));
   _blinkCursorTimer   = new QTimer(this);
   connect(_blinkCursorTimer, SIGNAL(timeout()), this, SLOT(blinkCursorEvent()));
 
+  KCursor::setAutoHideCursor( this, true );
+  
   setUsesMouse(true);
   setColorTable(base_color_table); 
-
-  KCursor::setAutoHideCursor( this, true );
-
   setMouseTracking(true);
 
-  // Init DnD 
+  // Enable drag and drop 
   setAcceptDrops(true); // attempt
   dragInfo.state = diNone;
 
@@ -649,7 +653,14 @@ void TerminalDisplay::drawCharacters(QPainter& painter,
     if ( isLineCharString(text) )
 	  	drawLineCharString(painter,rect.x(),rect.y(),text,style);
     else
-        painter.drawText(rect,text);
+	{
+		// the drawText(rect,flags,string) overload is used here with null flags
+		// instead of drawText(rect,string) because the (rect,string) overload causes 
+		// the application's default layout direction to be used instead of 
+		// the widget-specific layout direction, which should always be
+		// Qt::LeftToRight for this widget
+        painter.drawText(rect,0,text);
+	}
 }
 
 void TerminalDisplay::drawTextFragment(QPainter& painter , 
@@ -811,6 +822,9 @@ QRegion TerminalDisplay::hotSpotRegion() const
 
 void TerminalDisplay::processFilters() 
 {
+	if (!_screenWindow)
+		return;
+
 	QRegion preUpdateHotSpots = hotSpotRegion();
 
 	// use _screenWindow->getImage() here rather than _image because
@@ -912,7 +926,7 @@ void TerminalDisplay::updateImage()
         int p = 0;
         disstrU[p++] = c; //fontMap(c);
         bool lineDraw = isLineChar(c);
-        bool doubleWidth = (newLine[x+1].character == 0);
+        bool doubleWidth = (x+1 == columnsToUpdate) ? false : (newLine[x+1].character == 0);
         cr = newLine[x].rendition;
         _clipboard = newLine[x].backgroundColor;
         if (newLine[x].foregroundColor != cf) cf = newLine[x].foregroundColor;
@@ -924,12 +938,14 @@ void TerminalDisplay::updateImage()
             if (!ch.character)
                 continue; // Skip trailing part of multi-col chars.
 
+			bool nextIsDoubleWidth = (x+len+1 == columnsToUpdate) ? false : (newLine[x+len+1].character == 0);
+
             if (  ch.foregroundColor != cf || 
                   ch.backgroundColor != _clipboard || 
                   ch.rendition != cr ||
                   !dirtyMask[x+len] || 
                   isLineChar(c) != lineDraw || 
-                  (newLine[x+len+1].character == 0) != doubleWidth )
+                  nextIsDoubleWidth != doubleWidth )
             break;
 
           disstrU[p++] = c; //fontMap(c);
@@ -1009,46 +1025,35 @@ void TerminalDisplay::updateImage()
   delete[] dirtyMask;
   delete[] disstrU;
 
-  showResizeNotification();
 }
 
 void TerminalDisplay::showResizeNotification()
 {
-  if (_resizing && _terminalSizeHint)
+  if (_terminalSizeHint && isVisible())
   {
      if (_terminalSizeStartup) {
-       _terminalSizeStartup=false;
+       		_terminalSizeStartup=false;
        return;
      }
      if (!_resizeWidget)
      {
-        _resizeWidget = new QFrame(this);
+        _resizeWidget = new QLabel(i18n("Size: XXX x XXX"), this);
+        _resizeWidget->setMinimumWidth(_resizeWidget->fontMetrics().width(i18n("Size: XXX x XXX")));
+        _resizeWidget->setMinimumHeight(_resizeWidget->sizeHint().height());
+		_resizeWidget->setAlignment(Qt::AlignCenter);
 
-        QFont f = KGlobalSettings::generalFont();
-        int fs = f.pointSize();
-        if (fs == -1)
-           fs = QFontInfo(f).pointSize();
-        f.setPointSize((fs*3)/2);
-        f.setBold(true);
-        _resizeWidget->setFont(f);
-        _resizeWidget->setFrameShape((QFrame::Shape) (QFrame::Box|QFrame::Raised));
-        _resizeWidget->setMidLineWidth(2);
-        QBoxLayout *l = new QVBoxLayout(_resizeWidget);
-	    l->setMargin(10);
-        _resizeLabel = new QLabel(i18n("Size: XXX x XXX"), _resizeWidget);
-        l->addWidget(_resizeLabel, 1, Qt::AlignCenter);
-        _resizeWidget->setMinimumWidth(_resizeLabel->fontMetrics().width(i18n("Size: XXX x XXX"))+20);
-        _resizeWidget->setMinimumHeight(_resizeLabel->sizeHint().height()+20);
-        _resizeTimer = new QTimer(this);
-	_resizeTimer->setSingleShot(true);
+        _resizeWidget->setStyleSheet("background-color:palette(window);border-style:solid;border-width:1px;border-color:palette(dark)");
+
+		_resizeTimer = new QTimer(this);
+		_resizeTimer->setSingleShot(true);
         connect(_resizeTimer, SIGNAL(timeout()), _resizeWidget, SLOT(hide()));
      }
      QString sizeStr = i18n("Size: %1 x %2", _columns, _lines);
-     _resizeLabel->setText(sizeStr);
+     _resizeWidget->setText(sizeStr);
      _resizeWidget->move((width()-_resizeWidget->width())/2,
                          (height()-_resizeWidget->height())/2+20);
      _resizeWidget->show();
-     _resizeTimer->start(3000);
+     _resizeTimer->start(1000);
   }
 }
 
@@ -1071,8 +1076,7 @@ void TerminalDisplay::setBlinkingCursor(bool blink)
 
 void TerminalDisplay::paintEvent( QPaintEvent* pe )
 {
-  QPainter paint;
-  paint.begin( this );
+  QPainter paint(this);
 
   foreach (QRect rect, (pe->region() & contentsRect()).rects())
   {
@@ -1086,6 +1090,14 @@ void TerminalDisplay::paintEvent( QPaintEvent* pe )
   paint.end();
 }
 
+QPoint TerminalDisplay::cursorPosition() const
+{
+	if (_screenWindow)
+		return _screenWindow->cursorPosition();
+	else
+		return QPoint(0,0);
+}
+
 QRect TerminalDisplay::preeditRect() const
 {
     const int preeditLength = string_width(_inputMethodData.preeditString);
@@ -1093,8 +1105,8 @@ QRect TerminalDisplay::preeditRect() const
     if ( preeditLength == 0 )
         return QRect();
 
-    return QRect(_leftMargin + _fontWidth*_screenWindow->cursorPosition().x(),
-                 _topMargin + _fontHeight*_screenWindow->cursorPosition().y(),
+    return QRect(_leftMargin + _fontWidth*cursorPosition().x(),
+                 _topMargin + _fontHeight*cursorPosition().y(),
                  _fontWidth*preeditLength,
                  _fontHeight);
 }   
@@ -1104,7 +1116,7 @@ void TerminalDisplay::drawInputMethodPreeditString(QPainter& painter , const QRe
     if ( _inputMethodData.preeditString.isEmpty() )
         return;
 
-    const QPoint cursorPos = _screenWindow->cursorPosition();
+    const QPoint cursorPos = cursorPosition(); 
 
     bool invertColors = false;
     const QColor background = _colorTable[DEFAULT_BACK_COLOR].color;
@@ -1355,8 +1367,7 @@ void TerminalDisplay::blinkCursorEvent()
 {
   _cursorBlinking = !_cursorBlinking;
 
-  QPoint cursorPosition =_screenWindow->cursorPosition();
-  QRect cursorRect = imageToWidget( QRect(cursorPosition,QSize(1,1)) ); 
+  QRect cursorRect = imageToWidget( QRect(cursorPosition(),QSize(1,1)) ); 
 
   update(cursorRect);
 }
@@ -1415,6 +1426,7 @@ void TerminalDisplay::updateImageSize()
 
   if ( _resizing )
   {
+  	showResizeNotification();
     emit changedContentSizeSignal(_contentHeight, _contentWidth); // expose resizeEvent
   }
   
