@@ -221,6 +221,7 @@ void ViewManager::updateDetachViewState()
 	if (!_actionCollection)
 		return;
 
+
 	bool splitView = _viewSplitter->containers().count() >= 2;
 	bool shouldEnable = splitView || _viewSplitter->activeContainer()->views().count() >= 2;
 
@@ -401,12 +402,6 @@ void ViewManager::splitView(Qt::Orientation orientation)
 }
 void ViewManager::removeContainer(ViewContainer* container)
 {
-    // note that the _viewSplitter->containers().count() will not be updated
-    // until the container is deleted when Qt returns to the main event loop,
-    // so we take the previous container count and work out what the new count
-    // would be.
-    int previousCount = _viewSplitter->containers().count();
-
     // remove session map entries for views in this container
     foreach( QWidget* view , container->views() )
     {
@@ -415,8 +410,10 @@ void ViewManager::removeContainer(ViewContainer* container)
         _sessionMap.remove(display);
     } 
 
+	_viewSplitter->removeContainer(container);
     container->deleteLater();
-    emit splitViewToggle( (previousCount-1) > 1);
+
+    emit splitViewToggle( _viewSplitter->containers().count() > 1 );
 }
 void ViewManager::expandActiveView()
 {
@@ -571,7 +568,33 @@ ViewContainer* ViewManager::createContainer(const QString& profileKey)
     return container;
 }
 
-void ViewManager::setNavigationMethod(NavigationMethod method) { _navigationMethod = method; }
+void ViewManager::setNavigationMethod(NavigationMethod method)
+{
+    _navigationMethod = method;
+
+    KActionCollection* collection = _actionCollection;
+
+    if ( collection )
+    {
+        QAction* action;
+
+        action = collection->action( "next-view" );
+        if ( action ) action->setEnabled( _navigationMethod != NoNavigation );
+
+        action = collection->action( "previous-view" );
+        if ( action ) action->setEnabled( _navigationMethod != NoNavigation );
+
+        action = collection->action( "split-view-left-right" );
+        if ( action ) action->setEnabled( _navigationMethod != NoNavigation );
+
+        action = collection->action( "split-view-top-bottom" );
+        if ( action ) action->setEnabled( _navigationMethod != NoNavigation );
+
+        action = collection->action( "rename-session" );
+        if ( action ) action->setEnabled( _navigationMethod != NoNavigation );
+    }
+}
+
 ViewManager::NavigationMethod ViewManager::navigationMethod() const { return _navigationMethod; }
 
 void ViewManager::containerViewsChanged(QObject* container)
@@ -612,10 +635,10 @@ TerminalDisplay* ViewManager::createTerminalDisplay(Session* session)
    TerminalDisplay* display = new TerminalDisplay(0);
 
    //TODO Temporary settings used here
-   display->setBellMode(0);
-   display->setTerminalSizeHint(false);
+   display->setBellMode(TerminalDisplay::NotifyBell);
+   display->setTerminalSizeHint(true);
    display->setTripleClickMode(TerminalDisplay::SelectWholeLine);
-   display->setTerminalSizeStartup(false);
+   display->setTerminalSizeStartup(true);
    display->setScrollBarPosition(TerminalDisplay::ScrollBarRight);
    display->setRandomSeed(session->sessionId() * 31);
 
