@@ -6,7 +6,7 @@
   Copyright (c) 2000 Matthias Hoelzer-Kluepfel <hoelzer@kde.org>
                      Stefan Schimanski <1Stein@gmx.de>
                 2003-2005 George Staikos <staikos@kde.org>
-                2007 Maksim orlovich     <maksim@kde.org>
+                2007, 2008 Maksim Orlovich     <maksim@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -192,7 +192,7 @@ NPError g_NPN_GetValue(NPP /*instance*/, NPNVariable variable, void *value)
       case NPNVToolkit:
          // This is messy. OSS things want to see "Gtk2" here;
          // but commercial flash works better if we return something else.
-         // So we return a KHTML classic, since we can work with 
+         // So we return a KHTML classic, since we can work with
          // the community members far easier.
          *(NPNToolkitType*)value = (NPNToolkitType)0xFEEDABEE;
          return NPERR_NO_ERROR;
@@ -597,7 +597,7 @@ NPError g_NPN_SetValue(NPP /*instance*/, NPPVariable variable, void* /*value*/)
 static int s_instanceCounter = 0;
 
 NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
-                                   KLibrary *handle, int width, int height,
+                                   KLibrary *handle,
                                    const QString &src, const QString &/*mime*/,
                                    const QString &appId, const QString &callbackId,
                                    bool embed,
@@ -610,14 +610,11 @@ NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
    QDBusConnection::sessionBus().registerObject( objectName(), this );
 
     Q_UNUSED(embed);
-   _firstResize = true;
    _embedded = false;
    _npp = privateData;
    _npp->ndata = this;
    _destroyed = false;
    _handle = handle;
-   _width = width;
-   _height = height;
    _tempFiles.setAutoDelete( true );
    _streams.setAutoDelete( true );
    _waitingRequests.setAutoDelete( true );
@@ -636,33 +633,18 @@ NSPluginInstance::NSPluginInstance(NPP privateData, NPPluginFuncs *pluginFuncs,
    kDebug(1431) << "pdata = " << _npp->pdata;
    kDebug(1431) << "ndata = " << _npp->ndata;
 
-   if (width == 0)
-      width = 1600;
-
-   if (height == 0)
-      height = 1200;
-      
-   // Create our XEmbed peer with the part.
-   _outside = new QX11EmbedWidget();
-   _outside->hide();
-   _outside->setWindowTitle("nspluginviewer.outside");
-   
-   // We need to wait until we're embedded before being able to 
-   // do things.
-   connect(_outside, SIGNAL(embedded()), this, SLOT(embeddedIntoHost()));
-   
    // Create the appropriate host for the plugin type.
    _pluginHost = 0;
    int result = PR_FALSE;
-   
+
    //### iceweasel does something odd here --- it enabled XEmbed for swfdec,
    // even though that doesn't provide GetValue at all(!)
    if (NPGetValue(NPPVpluginNeedsXEmbed, &result) == NPERR_NO_ERROR && result) {
       kDebug(1431) << "plugin reqests XEmbed";
-      _pluginHost = new PluginHostXEmbed(this, _outside);
+      _pluginHost = new PluginHostXEmbed(this);
    } else {
       kDebug(1431) << "plugin requests Xt";
-      _pluginHost = new PluginHostXt(this, _outside, width, height);
+      _pluginHost = new PluginHostXt(this);
    }
 
    XSync(QX11Info::display(), false);
@@ -718,9 +700,6 @@ void NSPluginInstance::destroy()
 
         delete _pluginHost;
         _pluginHost = 0;
-        
-        delete _outside;
-        _outside = 0;
 
         if (_npp) {
             ::free(_npp);   // matched with malloc() in newInstance
@@ -835,7 +814,7 @@ void NSPluginInstance::timer()
 QString NSPluginInstance::normalizedURL(const QString& url) const {
 
     // ### for dfaure:  KUrl(KUrl("http://www.youtube.com/?v=JvOSnRD5aNk"), KUrl("javascript:window.location+"__flashplugin_unique__"));
-    
+
     //### hack, prolly evil, etc.
     if (url.startsWith("javascript:"))
        return url;
@@ -913,45 +892,30 @@ void NSPluginInstance::streamFinished( NSPluginStreamBase* strm )
    _timer->start( 100 );
 }
 
-void NSPluginInstance::embeddedIntoHost()
+void NSPluginInstance::setupWindow(int winId, int w, int h)
 {
-   _outside->show();
-   setupWindow();
+   kDebug(1431) << "-> NSPluginInstance::setupWindow( winid =" << winId << " w=" << w << ", h=" << h << " ) ";
+   if (_pluginHost)
+      _pluginHost->setupWindow(winId, w, h);
+   else
+    kWarning(1431) << "No plugin host!";
+
+   kDebug(1431) << "<- NSPluginInstance::setupWindow";
+   _width  = w;
+   _height = h;
    _embedded = true;
 }
 
-void NSPluginInstance::setupWindow()
+void NSPluginInstance::resizePlugin(int clientWinId, int w, int h)
 {
-   if (_pluginHost)
-      _pluginHost->setupWindow(_width, _height);
-}
-
-
-void NSPluginInstance::resizePlugin(int w, int h)
-{
-   kDebug(1431) << "-> NSPluginInstance::resizePlugin( w=" << w << ", h=" << h << " ) ";
-   if (!_embedded) {
-      _width = w;
-      _height = h;
+   kDebug() << _width << w << _height << h << _embedded;
+   if (!_embedded)
       return;
-   }
-
    if (w == _width && h == _height)
       return;
-
-   _width = w;
+   _pluginHost->resizePlugin(clientWinId, w, h);
+   _width  = w;
    _height = h;
-
-   _outside->resize(w, h);
-   if (_pluginHost)
-      _pluginHost->resizePlugin(w, h);
-
-   if (_firstResize) {
-      _firstResize = false;
-      setupWindow();
-   }
-
-   kDebug(1431) << "<- NSPluginInstance::resizePlugin";
 }
 
 
@@ -1138,6 +1102,34 @@ void NSPluginInstance::addTempFile(KTemporaryFile *tmpFile)
    _tempFiles.append(tmpFile);
 }
 
+static bool has_focus = false;
+
+void NSPluginInstance::gotFocusIn()
+{
+  has_focus = true;
+}
+
+void NSPluginInstance::gotFocusOut()
+{
+  has_focus = false;
+}
+
+#include <dlfcn.h>
+// Prevent plugins from polling the keyboard regardless of focus.
+static int (*real_xquerykeymap)( Display*, char[32] ) = NULL;
+
+extern "C" KDE_EXPORT
+int XQueryKeymap( Display* dpy, char k[32] )
+{
+    if( real_xquerykeymap == NULL )
+        real_xquerykeymap = (int (*)( Display*, char[32] )) dlsym( RTLD_NEXT, "XQueryKeymap" );
+    if( has_focus )
+        return real_xquerykeymap( dpy, k );
+    memset( k, 0, 32 );
+    return 1;
+}
+
+
 /***************************************************************************/
 
 NSPluginViewer::NSPluginViewer( QObject *parent )
@@ -1268,7 +1260,7 @@ NSPluginClass::NSPluginClass( const QString &library,
 
     // initialize plugin
     kDebug(1431) << "Plugin library " << library << " loaded!";
-    
+
     // see if it uses gtk
     if (!s_initedGTK) {
         gtkInitFunc* gtkInit = (gtkInitFunc*)_handle->resolveFunction("gtk_init");
@@ -1278,7 +1270,7 @@ NSPluginClass::NSPluginClass( const QString &library,
             s_initedGTK = true;
         }
     }
-    
+
     _constructed = true;
     _error = initialize()!=NPERR_NO_ERROR;
 }
@@ -1314,7 +1306,7 @@ int NSPluginClass::initialize()
    // initialize nescape exported functions
    memset(&_pluginFuncs, 0, sizeof(_pluginFuncs));
    memset(&_nsFuncs, 0, sizeof(_nsFuncs));
-   
+
    _pluginFuncs.size = sizeof(_pluginFuncs);
    _nsFuncs.size = sizeof(_nsFuncs);
    _nsFuncs.version = (NP_VERSION_MAJOR << 8) + NP_VERSION_MINOR;
@@ -1375,8 +1367,6 @@ QDBusObjectPath NSPluginClass::newInstance( const QString &url, const QString &m
    char **_argn = new char*[argc];
    char **_argv = new char*[argc];
    QString src = url;
-   int width = 0;
-   int height = 0;
    QString baseURL = url;
 
    for (unsigned int i=0; i<argc; i++)
@@ -1390,8 +1380,6 @@ QDBusObjectPath NSPluginClass::newInstance( const QString &url, const QString &m
       _argn[i] = strdup(n);
       _argv[i] = strdup(v);
 
-      if (!strcasecmp(_argn[i], "WIDTH")) width = argv[i].toInt();
-      if (!strcasecmp(_argn[i], "HEIGHT")) height = argv[i].toInt();
       if (!strcasecmp(_argn[i], "__KHTML__PLUGINBASEURL")) baseURL = _argv[i];
       kDebug(1431) << "argn=" << _argn[i] << " argv=" << _argv[i];
    }
@@ -1409,8 +1397,8 @@ QDBusObjectPath NSPluginClass::newInstance( const QString &url, const QString &m
 
    // Create plugin instance object
    NSPluginInstance *inst = new NSPluginInstance( npp, &_pluginFuncs, _handle,
-                                                  width, height, baseURL, mimeType,
-                                                  appId, callbackId, embed, this );
+                                                  baseURL, mimeType, appId,
+                                                  callbackId, embed, this );
 
    // create plugin instance
    NPError error = _pluginFuncs.newp(mime, npp, embed ? NP_EMBED : NP_FULL,
@@ -1549,6 +1537,12 @@ bool NSPluginStreamBase::create( const QString& url, const QString& mimeType, vo
     return true;
 }
 
+void NSPluginStreamBase::updateURL( const KUrl& newURL )
+{
+    _url = newURL;
+    free(const_cast<char*>(_stream->url));
+    _stream->url = strdup(_url.url().toLatin1().data());
+}
 
 int NSPluginStreamBase::process( const QByteArray &data, int start )
 {
@@ -1776,6 +1770,8 @@ bool NSPluginStream::get( const QString& url, const QString& mimeType,
                 SLOT(totalSize(KJob *, qulonglong)));
         connect(_job, SIGNAL(mimetype(KIO::Job *, const QString &)),
                 SLOT(mimetype(KIO::Job *, const QString &)));
+        connect(_job, SIGNAL(redirection(KIO::Job *, const KUrl&)),
+                SLOT(redirection(KIO::Job *, const KUrl&)));
     }
 
     return false;
@@ -1801,6 +1797,8 @@ bool NSPluginStream::post( const QString& url, const QByteArray& data,
                 SLOT(totalSize(KJob *, qulonglong)));
         connect(_job, SIGNAL(mimetype(KIO::Job *, const QString &)),
                 SLOT(mimetype(KIO::Job *, const QString &)));
+        connect(_job, SIGNAL(redirection(KIO::Job *, const KUrl&)),
+                SLOT(redirection(KIO::Job *, const KUrl&)));
     }
 
     return false;
@@ -1818,6 +1816,11 @@ void NSPluginStream::data(KIO::Job*, const QByteArray &data)
     }
 }
 
+void NSPluginStream::redirection(KIO::Job * /*job*/, const KUrl& url)
+{
+    updateURL(url);
+}
+
 void NSPluginStream::totalSize(KJob * job, qulonglong size)
 {
     kDebug(1431) << "NSPluginStream::totalSize - job=" << (void*)job << " size=" << KIO::number(size);
